/************************************************************/
/* ALL SECTIONS OF THE CODE THAT REQUIRE EDITS ARE PRECEDED */
/* BY A COMMENT BOX LIKE THIS ONE AND BEGIN WITH "STEP #:"  */
/* PLEASE ONLY EDIT CODE AS INSTRUCTED BY COMMENT BOXES     */
/* ASSOCIATED WITH EACH STEP                                */
/************************************************************/

PROC DATASETS LIB = WORK KILL;
QUIT;

/**********************************************************************/
/* STEP 1: CHANGE DATAFILE LOCATION (SINGLE YEAR OR MERGED DUMMY DATA)*/
LIBNAME CHIS "D:\USER\Data\Dummy Data\CHIS 2020\ADULT_SAS_DUMMY_2020";
LIBNAME MVL "D:\USER\Code for Site\Dummy Data Prep\Final";
LIBNAME OUTFILE "D:\USER\Dummy data project\Dummy DATA";

/*****************************************************************************/
/*STEP 2: CHANGE "COMBINED" TO NAME OF MERGED DATASET IN YOUR DIRECTORY */
/* NOTE: IF YOU ARE USING SINGLE YEAR DATA AND DO NOT HAVE A YEAR VARIABLE IN */
/* YOUR DUMMY DATA SET, REMOVE "YEAR" FROM THE "KEEP" STATEMENT */


%MACRO setfinal;
DATA FINAL;
	SET CHIS.COMBINED(KEEP=&proxy1 BASEID YEAR RAKEDW0-RAKEDW80);
RUN;
%MEND;


/***************************************************************************/
/* STEP 3: SET MASTER VARIABLE LIST LOCATION */
%let DPTAB = MVL.CityofBerkley_MVL_2020.xlsx;



/* SET FINAL DATASET */
%let OUTFILE = OUTFILE.[SPECIFY FINAL DATASET NAME];

/********************************************************************/
/*Import MVL Excel table */
/********************************************************************/

%MACRO xlimp(sheet);
PROC IMPORT OUT=PROXY_&SHEET DATAFILE="&DPTAB" DBMS=EXCEL REPLACE; SHEET="&SHEET"; GETNAMES=YES; 
RUN;
%MEND;


/*********************************************************************************************************/
/* STEP 4: REMOVE UNNEEDED LINES OF CODE                                                                  */
/* 	This step imports sheets from the MVL Excel tables.                                                */
/*********************************************************************************************************/

%xlimp(ADULT);
%xlimp(TEEN);
%xlimp(CHILD);


/************************************************************************************************************/
/* STEP 5: REMOVE UNNEEDED DATASETS                                                                          */
/*  This step combines the datasets that were imported in the last step. Remove the "PROXY_" dataset(s)     */
/*  from the "SET" statement that were not produced in the previous step                                    */
/************************************************************************************************************/

DATA APP_DATA; 
LENGTH VARIABLE_NAME $ 13;
SET PROXY_ADULT PROXY_TEEN PROXY_CHILD; 
RUN;


/****************************************************************************************************/
/*																									*/
/* PLEASE SKIP TO STEP 6 AT THE END OF THE CODE. DO NOT EDIT ANY CODE BETWEEN THIS POINT AND STEP 6 */
/*																									*/
/****************************************************************************************************/


/*The following steps create a dataset with only the selected variables*/
DATA MVLS; SET APP_DATA;
	IF whichc('X', of CHIS_20:) 
	OR whichc('x', of CHIS_20:)
	OR whichc('Y', of CHIS_20:)
	OR whichc('y', of CHIS_20:);
RUN;

DATA VAR_NAMES; 
	SET MVLS;
	KEEP VARIABLE_NAME;
RUN;



/*********************************************************************************/
/* STEP 6: Set final dataset (options for macro in step 1)           */
/*********************************************************************************/

%setfinal;


/***********************************************************************************/
/* STEP 7: Export datasets--SET OUTFILE LOCATION WITH FILE NAME FOR FINAL DATASET  */
/*  EXPORT TO STATA DATASET. USE CODE BELOW FOR SAS DATASET                        */
/***********************************************************************************/

PROC EXPORT DATA=WORK.FINAL
	OUTFILE = "&OUTFILE"
	dbms=dta;
RUN;

/**EXPORT TO SAS DATASET*/
LIBNAME OUT '&OUTFILE';
	DATA OUT.FINAL_DUMMY_DATA;
		SET FINAL;
RUN;
